# momi

momi (MOran Models for Inference) is a Python package that computes
the expected sample frequency spectrum (SFS), a statistic commonly used
in population genetics, and uses it to fit demographic history.

See the [documentation](http://momi2.readthedocs.io/en/latest/)
for installation instructions, tutorial, and API reference.

The paper describing the method is:

Kamm, J., Terhorst, J., Durbin, R., and Song, Y.S.
Efficiently inferring the demographic history of many populations with allele count data.  Journal of the American Statistical Association, Vol. 115, No. 531, (2020) 1472-1487.  [ [Link](https://www.tandfonline.com/doi/full/10.1080/01621459.2019.1635482) ]
